@@ -8,19 +8,30 @@ BEGIN {
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Moo;
 use MIDI::Simple;
 
+
 sub BUILDARGS
 {
    my ( $class, %args ) = @_;
 
-    $args{channel} ||= 9;
-    $args{volume}  ||= 100;
-    $args{bpm}     ||= 120;
-    $args{score}   ||= MIDI::Simple->new_score;
+    $args{channel}   ||= 9;
+    $args{volume}    ||= 100;
+    $args{bpm}       ||= 120;
+    $args{signature} ||= '4/4';
+    $args{score}     ||= MIDI::Simple->new_score;
+
+    ($args{beats}, $args{divisions}) = split /\//, $args{signature};
+
+    $args{score}->time_signature(
+        $args{beats},
+        sqrt( $args{divisions} ),
+        ( $args{divisions} == 8 ? 24 : 18 ),
+        8
+    );
 
     $args{score}->noop( 'c' . $args{channel}, 'V' . $args{volume} );
     $args{score}->set_tempo( int( 60_000_000 / $args{bpm} ) );
@@ -35,36 +46,21 @@ sub BUILDARGS
    return \%args;
 }
 
-has file => ( is => 'ro', default => sub { 'MIDI-Drummer.mid' } );
+
 has channel => ( is => 'ro' );
 has volume => ( is => 'ro' );
 has bpm => ( is => 'ro' );
 has reverb => ( is => 'ro' );
 has chorus => ( is => 'ro' );
 has pan => ( is => 'ro' );
+has beats => ( is => 'ro' );
+has divisions => ( is => 'ro' );
+has signature => ( is => 'ro' );
 has score => ( is => 'ro' );
+
+has file => ( is => 'ro', default => sub { 'MIDI-Drummer.mid' } );
 has bars => ( is => 'ro', default => sub { 4 } );
-has signature => ( is => 'ro', default => sub { '4/4' } );
 
-has beats => (
-    is => 'ro',
-    lazy => 1,
-    default => sub {
-        my $self = shift;
-        my ($beats) = split /\//, $self->signature;
-        return $beats;
-    },
-);
-
-has divisions => (
-    is => 'ro',
-    lazy => 1,
-    default => sub {
-        my $self = shift;
-        my ($beats, $divs) = split /\//, $self->signature;
-        return $divs;
-    },
-);
 
 # kit
 has kick          => ( is => 'ro', default => sub { 'n35' } );
@@ -86,6 +82,7 @@ has low_tom       => ( is => 'ro', default => sub { 'n45' } );
 has hi_floor_tom  => ( is => 'ro', default => sub { 'n43' } );
 has low_floor_tom => ( is => 'ro', default => sub { 'n41' } );
 
+
 # duration
 has whole => ( is => 'ro', default => sub { 'wn' } );
 has half => ( is => 'ro', default => sub { 'hn' } );
@@ -93,25 +90,38 @@ has quarter => ( is => 'ro', default => sub { 'qn' } );
 has eighth => ( is => 'ro', default => sub { 'en' } );
 has sixteenth => ( is => 'ro', default => sub { 'sn' } );
 
+
 sub note { return shift->score->n(@_) }
+
+
 sub rest { return shift->score->r(@_) }
 
+
 sub count_in {
     my $self = shift;
-    my $bars = shift || $self->bars;
-    for my $i ( 1 .. $self->beats * $bars ) {
+    my $bars = shift || 1;
+    for my $i ( 1 .. $self->beats * $bars) {
         $self->note( $self->quarter, $self->closed_hh );
     }
 }
 
+
+
 sub metronome {
     my $self = shift;
     my $bars = shift || $self->bars;
     for my $n ( 1 .. $self->beats * $bars ) {
-        $self->note( $self->quarter, $self->open_hh, $n % 2 ? $self->kick : $self->snare );
+        if ( $self->beats % 2 == 0 )
+        {
+            $self->note( $self->quarter, $self->open_hh, $n % 2 ? $self->kick : $self->snare );
+        }
+        else {
+            $self->note( $self->quarter, $self->open_hh, $n % 3 ? $self->kick : $self->snare );
+        }
     }
 }
 
+
 sub write {
     my $self = shift;
     $self->score->write_score( $self->file );
@@ -131,7 +141,132 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.01
+version 0.02
+
+=head1 SYNOPSIS
+
+ use MIDI::Drummer::Tiny;
+ my $d = MIDI::Drummer::Tiny->new(
+    file => 'drums.mid',
+    bpm => 120,
+    signature => '4/4',
+    bars => 32,
+ );
+ $d->count_in();
+ $d->metronome();
+ $d->write();
+
+=head1 DESCRIPTION
+
+This module provides a MIDI drummer with the bare essentials to add notes to a
+MIDI score.
+
+=head1 ATTRIBUTES
+
+=head2 channel: 9
+
+=head2 volume: 100
+
+=head2 bpm: 120
+
+=head2 reverb: 0
+
+=head2 chorus: 0
+
+=head2 pan: 0
+
+=head2 bars: 4
+
+=head2 beats: 4
+
+=head2 divisions: 4
+
+=head2 signature: 4/4
+
+=head2 file: MIDI-Drummer.mid
+
+=head2 score
+
+=head1 KIT
+
+=head2 kick
+
+=head2 snare
+
+=head2 open_hh
+
+=head2 closed_hh
+
+=head2 pedal_hh
+
+=head2 crash1
+
+=head2 crash2
+
+=head2 splash
+
+=head2 china
+
+=head2 ride1
+
+=head2 ride2
+
+=head2 ride_bell
+
+=head2 hi_tom
+
+=head2 hi_mid_tom
+
+=head2 low_mid_tom
+
+=head2 low_tom
+
+=head2 hi_floor_tom
+
+=head2 low_floor_tom
+
+=head1 DURATIONS
+
+=head2 whole
+
+=head2 half
+
+=head2 quarter
+
+=head2 eighth
+
+=head2 sixteenth
+
+=head1 METHODS
+
+=head2 note()
+
+ $d->note( $d->quarter, $d->closed_hh, $d->kick );
+ $d->note( 'qn', 'n42', 'n35' ); # Same thing
+
+Send a note to the score.
+
+=head2 rest()
+
+ $d->rest( $d->quarter );
+
+Send a rest to the score.
+
+=head2 count_in()
+
+ $d->count_in;
+ $d->count_in($bars);
+
+Play the closed hihat for the number of beats times the given bars.
+If no bars are given, the default of 1 is used.
+
+=head2 metronome()
+
+Add a steady beat to the score.
+
+=head2 write()
+
+Output the score to a F<*.mid> file.
 
 =head1 AUTHOR
 
